{% extends "admin/change_list.html" %}

{% block object-tools-items %}
    <li>
        <!-- REMOVED 'addlink' class from all buttons -->
        <a href="test-dropbox/" class="button" style="background-color: #f5f5f5; color: #333; border: 1px solid #ccc; padding: 8px 15px; border-radius: 4px; font-weight: bold; text-transform: uppercase; font-size: 11px;">
            Test Dropbox Connection
        </a>
    </li>
    <li>
        <a href="upload-restore/" class="button" style="background-color: #d32f2f; color: white; border: none; padding: 8px 15px; border-radius: 4px; font-weight: bold; text-transform: uppercase; font-size: 11px; margin-left: 10px;">
            Upload & Restore
        </a>
    </li>
    <li>
        <a href="trigger-backup/?local=1" class="button" style="background-color: #417690; color: white; border: none; padding: 8px 15px; border-radius: 4px; font-weight: bold; text-transform: uppercase; font-size: 11px; margin-left: 10px;">
            Local Backup
        </a>
    </li>
    <li>
        <a href="trigger-backup/" class="button" style="background-color: #417690; color: white; border: none; padding: 8px 15px; border-radius: 4px; font-weight: bold; text-transform: uppercase; font-size: 11px; margin-left: 10px;">
            Cloud Backup
        </a>
    </li>
    {{ block.super }}
{% endblock %}