# Generated by Django 6.0.2 on 2026-03-09 15:55

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_db_backups', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='MediaBackupRecord',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('size_bytes', models.BigIntegerField(default=0)),
                ('storage_location', models.CharField(max_length=255)),
                ('status', models.CharField(choices=[('pending', 'Pending'), ('success', 'Success'), ('failed', 'Failed')], default='pending', max_length=20)),
                ('error_message', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Media Backup Log',
                'verbose_name_plural': 'Media Backup Logs',
                'ordering': ['-created_at'],
            },
        ),
        migrations.CreateModel(
            name='MediaRestoreRecord',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('source', models.CharField(max_length=255)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('status', models.CharField(choices=[('pending', 'Pending'), ('success', 'Success'), ('failed', 'Failed')], default='pending', max_length=20)),
                ('logs', models.TextField(blank=True)),
                ('error_message', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Media Restore Log',
                'verbose_name_plural': 'Media Restore Logs',
                'ordering': ['-created_at'],
            },
        ),
    ]
